import { MutableRefObject, useEffect, useRef } from 'react';
import { BrowserQRCodeReader, IScannerControls } from '@zxing/browser';

import { UseQrScannerHook } from '../types';

import { isMediaDevicesSupported, isValidType } from './utils';

// TODO: add support for debug logs
export const useQrScanner: UseQrScannerHook = ({
  scanDelay: delayBetweenScanAttempts,
  constraints: video,
  onSuccess,
  videoId,
}) => {
  const controlsRef: MutableRefObject<IScannerControls> = useRef(null);

  useEffect(() => {
    const codeScanner = new BrowserQRCodeReader(null, {
      delayBetweenScanAttempts,
    });

    if (
      !isMediaDevicesSupported() &&
      isValidType(onSuccess, 'onSuccess', 'function')
    ) {
      const message =
        'MediaDevices API has no support for your browser. You can fix this by running "npm i webrtc-adapter"';

      onSuccess(null, new Error(message), codeScanner);
    }

    if (isValidType(video, 'constraints', 'object')) {
      codeScanner
        .decodeFromConstraints({ video }, videoId, (result, error) => {
          if (isValidType(onSuccess, 'onSuccess', 'function')) {
            onSuccess(result, error, codeScanner);
          }
        })
        .then((controls: IScannerControls) => (controlsRef.current = controls))
        .catch((error: Error) => {
          if (isValidType(onSuccess, 'onSuccess', 'function')) {
            onSuccess(null, error, codeScanner);
          }
        });
    }

    return () => {
      controlsRef.current?.stop();
    };
  }, []);
};
