import * as React from 'react';

import { styles } from './styles';
import { useQrScanner } from './hooks';

import { QrScannerProps } from '../types';

export const QrScanner: React.FC<QrScannerProps> = ({
  videoContainerStyle,
  containerStyle,
  videoStyle,
  constraints,
  ViewFinder,
  scanDelay,
  className,
  onSuccess,
  videoId,
}) => {
  useQrScanner({
    constraints,
    scanDelay,
    onSuccess,
    videoId,
  });

  let showScanner = true;

  return (
    <section className={className} style={containerStyle}>
      {showScanner && (
        <div
          style={{
            ...styles.container,
            ...videoContainerStyle,
          }}
        >
          {!!ViewFinder && <ViewFinder />}
          <video
            muted
            id={videoId}
            style={{
              ...styles.video,
              ...videoStyle,
              transform: constraints?.facingMode === 'user' && 'scaleX(-1)',
            }}
          />
        </div>
      )}
    </section>
  );
};

QrScanner.displayName = 'QrScanner';
QrScanner.defaultProps = {
  constraints: {
    facingMode: 'user',
  },
  videoId: 'video',
  scanDelay: 500,
};
